django\_sorcery.management.commands.sorcery\_dropall module
===========================================================

.. automodule:: django_sorcery.management.commands.sorcery_dropall
    :members:
    :undoc-members:
    :show-inheritance:
